@@ -50,7 +50,7 @@ struct _BonoboUIHandler {
 	 * containee) manages the actual menu and toolbar item
 	 * GtkWidgets.
 	 */
-	Bonobo_UIHandler			 top_level_uih;
+	Bonobo_UIHandler		 top_level_uih;
 
 	/*
 	 * The callback data for the menu items.
@@ -74,55 +74,6 @@ struct _BonoboUIHandler {
 	BonoboUIHandlerPrivate *priv;
 };
 
-/*
- * The data which a top-level UIHandler server must maintain.
- */
-struct _BonoboUIHandlerTopLevelData {
-	/*
-	 * These hash tables are used to maintain an internal
-	 * representation of the menu and toolbar trees.  They store
-	 * internal data structures which you shouldn't muck with.
-	 */
-	GHashTable			*path_to_menu_item;
-
-	GHashTable			*path_to_toolbar_item;
-	GHashTable			*name_to_toolbar;
-
-	/*
-	 * Some application-global widget data.
-	 */
-	GnomeApp			*app;
-	GtkAccelGroup			*accelgroup;
-	GtkWidget			*statusbar;
-	GtkWidget			*menubar;
-	GtkWidget			*common_toolbar;
-	GHashTable			*toolbars;
-
-	/*
-	 * This hash table maps menu item paths to the actual
-	 * GtkMenuItem widgets.
-	 */
-	GHashTable			*path_to_menu_widget;
-
-	/*
-	 * This hash table maps subtree paths to the GtkMenuShell
-	 * widget.
-	 */
-	GHashTable			*path_to_menu_shell;
-
-	/* FIXME: Comments */
-	GHashTable			*name_to_toolbar_widget;
-	GHashTable			*path_to_toolbar_item_widget;
-
-	/*
-	 * If this UIHandler is for a top-level application which is
-	 * acting as a container for one or more embedded objects,
-	 * then this list contains the interfaces for the
-	 * BonoboUIHandlers for the embedded objects.
-	 */
-	GList				*containee_uihs;
-};
-
 typedef struct {
 	BonoboObjectClass parent_class;
 
@@ -257,6 +208,7 @@ char			*bonobo_ui_handler_build_path_v			(va_list path_components);
 
 /* Toplevel menu routines. */
 void			 bonobo_ui_handler_set_app			(BonoboUIHandler *uih, GnomeApp *app);
+GnomeApp                *bonobo_ui_handler_get_app                      (BonoboUIHandler *uih);
 void			 bonobo_ui_handler_set_statusbar			(BonoboUIHandler *uih, GtkWidget *statusbar);
 GtkWidget		*bonobo_ui_handler_get_statusbar			(BonoboUIHandler *uih);
 
@@ -379,8 +331,8 @@ char			*bonobo_ui_handler_menu_get_radio_group_selection(BonoboUIHandler *uih, c
  *
  * The name of the toolbar is the first element in the toolbar path.
  * For example:
- *		"Common/Save"
- *		"Graphics Tools/Erase"
+ *		"/Common/Save"
+ *		"/Graphics Tools/Erase"
  * 
  * Where both "Common" and "Graphics Tools" are the names of 
  * toolbars.
@@ -402,7 +354,7 @@ void				 bonobo_ui_handler_toolbar_new		(BonoboUIHandler *uih, const char *path,
 									 const char *label, const char *hint,
 									 int pos, const Bonobo_Control control,
 									 BonoboUIHandlerPixmapType pixmap_type,
-									 gconstpointer pixmap_data, guint accelerator_key,
+									 gpointer pixmap_data, guint accelerator_key,
 									 GdkModifierType ac_mods,
 									 BonoboUIHandlerCallbackFunc callback,
 									 gpointer callback_data);
@@ -411,7 +363,7 @@ void				 bonobo_ui_handler_toolbar_new_control	(BonoboUIHandler *uih, const char
 void				 bonobo_ui_handler_toolbar_new_item	(BonoboUIHandler *uih, const char *path,
 									 const char *label, const char *hint, int pos,
 									 BonoboUIHandlerPixmapType pixmap_type,
-									 gconstpointer pixmap_data,
+									 gpointer pixmap_data,
 									 guint accelerator_key, GdkModifierType ac_mods,
 									 BonoboUIHandlerCallbackFunc callback,
 									 gpointer callback_data);
@@ -495,9 +447,26 @@ gboolean			 bonobo_ui_handler_toolbar_item_toggle_get_state (BonoboUIHandler *ui
 gboolean			 bonobo_ui_handler_toolbar_item_radio_get_state  (BonoboUIHandler *uih, const char *path);
 void				 bonobo_ui_handler_toolbar_item_radio_set_state  (BonoboUIHandler *uih, const char *path, gboolean state);
 
-void                             bonobo_ui_handler_toolbar_item_set_orientation (BonoboUIHandler *uih, const char *path,
+void                             bonobo_ui_handler_toolbar_set_orientation (BonoboUIHandler *uih, const char *path,
 										GtkOrientation orientation);
-GtkOrientation                   bonobo_ui_handler_toolbar_item_get_orientation (BonoboUIHandler *uih, const char *path);
+GtkOrientation                   bonobo_ui_handler_toolbar_get_orientation (BonoboUIHandler *uih, const char *path);
+
+
+gboolean  bonobo_ui_handler_dock_add            (BonoboUIHandler       *uih,
+						 const char            *name,
+						 Bonobo_Control         control,
+						 GnomeDockItemBehavior  behavior,
+						 GnomeDockPlacement     placement,
+						 gint                   band_num,
+						 gint                   band_position,
+						 gint                   offset);
+gboolean  bonobo_ui_handler_dock_remove         (BonoboUIHandler       *uih,
+						 const char            *name);
+gboolean  bonobo_ui_handler_dock_set_sensitive  (BonoboUIHandler       *uih,
+						 const char            *name,
+						 gboolean               sensitivity);
+gboolean  bonobo_ui_handler_dock_get_sensitive  (BonoboUIHandler       *uih,
+						 const char            *name);
 
 extern POA_Bonobo_UIHandler__vepv bonobo_ui_handler_vepv;
 POA_Bonobo_UIHandler__epv *bonobo_ui_handler_get_epv (void);
