@@ -2,14 +2,14 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
+#include <bonobo/Bonobo.h>
 #include <bonobo/bonobo.h>
-#include <bonobo/gnome-bonobo.h>
 
 CORBA_Environment ev;
 CORBA_ORB orb;
 
-static GnomeCanvasComponent *
-item_create (GnomeView *view, GnomeCanvas *canvas, void *data)
+static BonoboCanvasComponent *
+item_factory (BonoboEmbeddable *bonobo_object, GnomeCanvas *canvas, void *data)
 {
 	GnomeCanvasItem *item;
 
@@ -24,36 +24,26 @@ item_create (GnomeView *view, GnomeCanvas *canvas, void *data)
 		"fill_color", "blue",
 		NULL);
 
-	return gnome_canvas_component_new (item);
+	return bonobo_canvas_component_new (item);
 }
 
-static GnomeView *
-item_factory (GnomeEmbeddable *bonobo_object, const GNOME_ViewFrame view_frame, void *data)
+static BonoboObject *
+bonobo_item_factory (BonoboEmbeddableFactory *factory, void *closure)
 {
-	GnomeView *view;
-
-	view = gnome_view_new_canvas (item_create, NULL);
-	
-	return view;
-}
-
-static GnomeObject *
-bonobo_item_factory (GnomeEmbeddableFactory *factory, void *closure)
-{
-	GnomeEmbeddable *server;
+	BonoboEmbeddable *server;
 
 	printf ("I am in item factory\n");
-	server =  gnome_embeddable_new (item_factory, NULL);
+	server =  bonobo_embeddable_new_canvas_item (item_factory, NULL);
 	if (server == NULL)
-		g_error ("Can not create gnome_embeddable");
+		g_error ("Can not create bonobo_embeddable");
 
-	return (GnomeObject*) server;
+	return (BonoboObject*) server;
 }
 
 static void
 init_server_factory (void)
 {
-	gnome_embeddable_factory_new (
+	bonobo_embeddable_factory_new (
 		"Test_item_server_factory", bonobo_item_factory, NULL);
 }
 
