@@ -2,43 +2,43 @@
 #include <config.h>
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
+#include <bonobo/Bonobo.h>
 #include <bonobo/bonobo.h>
-#include <bonobo/gnome-bonobo.h>
 
 CORBA_Environment ev;
 CORBA_ORB orb;
 
-static GnomeView *
-view_factory (GnomeEmbeddable *bonobo_object, const GNOME_ViewFrame view_frame, void *data)
+static BonoboView *
+view_factory (BonoboEmbeddable *bonobo_object, const Bonobo_ViewFrame view_frame, void *data)
 {
-	GnomeView *view;
+	BonoboView *view;
 	GtkWidget *widget;
 	
 
 	widget = gtk_hbox_new (0, 0);
 	gtk_container_add (GTK_CONTAINER (widget), gtk_entry_new ());
 	gtk_widget_show_all (widget);
-	view = gnome_view_new (widget);
+	view = bonobo_view_new (widget);
 	
 	return view;
 }
 
-static GnomeObject *
-bonobo_object_factory (GnomeEmbeddableFactory *factory, void *closure)
+static BonoboObject *
+bonobo_object_factory (BonoboEmbeddableFactory *factory, void *closure)
 {
-	GnomeEmbeddable *server;
+	BonoboEmbeddable *server;
 	
-	server =  gnome_embeddable_new (view_factory, NULL);
+	server =  bonobo_embeddable_new (view_factory, NULL);
 	if (server == NULL)
-		g_error ("Can not create gnome_embeddable");
+		g_error ("Can not create bonobo_embeddable");
 
-	return (GnomeObject*) server;
+	return (BonoboObject*) server;
 }
 
 static void
 init_server_factory (void)
 {
-	gnome_embeddable_factory_new (
+	bonobo_embeddable_factory_new (
 		"Test_server_factory", bonobo_object_factory, NULL);
 }
 
