@@ -198,15 +198,13 @@ add_view (GtkWidget *widget, Application *app,
 	GtkWidget *view_widget;
 	GtkWidget *frame;
 	
-	view_frame = bonobo_client_site_new_view (client_site);
+	view_frame = bonobo_client_site_new_view (client_site, CORBA_OBJECT_NIL);
 
 	gtk_signal_connect (GTK_OBJECT (view_frame), "user_activate",
 			    GTK_SIGNAL_FUNC (user_activation_request_cb), NULL);
 	gtk_signal_connect (GTK_OBJECT (view_frame), "view_activated",
 			    GTK_SIGNAL_FUNC (view_activated_cb), NULL);
 
-	bonobo_view_frame_set_ui_handler (view_frame, app->uih);
-
 	view_widget = bonobo_view_frame_get_wrapper (view_frame);
 
 	frame = gtk_frame_new ("Embeddable");
@@ -273,8 +271,8 @@ add_image_cmd (GtkWidget *widget, Application *app)
 
 	image_png_obj = object;
 
-	persist = bonobo_object_client_query_interface (object,
-						       "IDL:GNOME/PersistStream:1.0", NULL);
+	persist = bonobo_object_client_query_interface (
+		object, "IDL:Bonobo/PersistStream:1.0", NULL);
 
         if (persist == CORBA_OBJECT_NIL) {
 		printf ("No persist-stream interface\n");
@@ -314,8 +312,8 @@ add_pdf_cmd (GtkWidget *widget, Application *app)
 
 	image_png_obj = object;
 
-	persist = bonobo_object_client_query_interface (object,
-						       "IDL:GNOME/PersistStream:1.0", NULL);
+	persist = bonobo_object_client_query_interface (
+		object, "IDL:Bonobo/PersistStream:1.0", NULL);
 
         if (persist == CORBA_OBJECT_NIL)
                 return;
@@ -532,7 +530,7 @@ add_text_cmd (GtkWidget *widget, Application *app)
 	text_obj = object;
 
 	persist = bonobo_object_client_query_interface (object,
-		"IDL:GNOME/PersistStream:1.0", &ev);
+		"IDL:Bonobo/PersistStream:1.0", &ev);
 
         if (ev._major != CORBA_NO_EXCEPTION)
                 return;
@@ -632,7 +630,7 @@ send_text_cmd (GtkWidget *widget, Application *app)
 		return;
 
 	psink = bonobo_object_client_query_interface (text_obj,
-                 "IDL:GNOME/ProgressiveDataSink:1.0", NULL);
+                 "IDL:Bonobo/ProgressiveDataSink:1.0", NULL);
 
         if (psink == CORBA_OBJECT_NIL)
                 return;
