@@ -401,7 +401,8 @@ text_deleted_cb (GtkText *text,
 	return FALSE;
 } /* text_deleted_cb */
 
-static gint
+
+static void
 clear_text_cb (BonoboUIHandler *uih, void *data,
 	       const char *path)
 {
@@ -411,7 +412,6 @@ clear_text_cb (BonoboUIHandler *uih, void *data,
 	blank_all_views (view_data->bonobo_object_data);
 	free_text (view_data->bonobo_object_data);
 
-	return FALSE;
 } /* clear_text_cb */
 
 
@@ -695,14 +695,13 @@ progressive_add_data (BonoboProgressiveDataSink *psink,
  * BonoboObject construction functions.
  */
 static BonoboView *
-view_factory (BonoboEmbeddable *bonobo_object,
-	      const Bonobo_ViewFrame view_frame,
-	      void *data)
+view_factory (BonoboEmbeddable       *bonobo_object,
+	      const Bonobo_ViewFrame  view_frame,
+	      void                   *data)
 {
-        BonoboView *view;
-	BonoboUIHandler *uih;
 	bonobo_object_data_t *bonobo_object_data = data;
-	view_data_t *view_data;
+        BonoboView           *view;
+	view_data_t          *view_data;
 
 	/*
 	 * Create the private view data and the GtkText widget.
@@ -776,9 +775,6 @@ view_factory (BonoboEmbeddable *bonobo_object,
         view = bonobo_view_new (view_data->table);
 	view_data->view = view;
 
-	uih = bonobo_ui_handler_new ();
-	bonobo_view_set_ui_handler (view, uih);
-
 	bonobo_view_set_view_frame (view, view_frame);
 
 	gtk_signal_connect (GTK_OBJECT (view), "destroy",
@@ -823,7 +819,7 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	}
 	running_objects++;
 
-	gtk_signal_connect (GTK_OBJECT (bonobo_object), "destroy",
+	gtk_signal_connect_after (GTK_OBJECT (bonobo_object), "destroy",
 			    GTK_SIGNAL_FUNC (bonobo_object_destroy_cb),
 			    bonobo_object_data);
 
