@@ -181,8 +181,10 @@ buffer_add_view (Buffer *buffer, Frame *frame, gint pos)
 	GtkWidget *view_widget;
 	GtkWidget *box,*l;
 
-	view_frame = bonobo_client_site_new_view_full (buffer->client_site,
-						      FALSE, TRUE);
+	view_frame = bonobo_client_site_new_view_full (
+		buffer->client_site,
+		bonobo_object_corba_objref (BONOBO_OBJECT (frame->uih)),
+		FALSE, TRUE);
 
 	if (!view_frame) {
 		g_warning("create view failed");
@@ -196,11 +198,9 @@ buffer_add_view (Buffer *buffer, Frame *frame, gint pos)
 			    view_system_exception_cb, buffer);
 	gtk_signal_connect (GTK_OBJECT (view_frame), "user_activate",
 			    GTK_SIGNAL_FUNC (user_activate_request_cb), frame);
-	gtk_signal_connect (GTK_OBJECT (view_frame), "view_activated",
+	gtk_signal_connect (GTK_OBJECT (view_frame), "activated",
 			    GTK_SIGNAL_FUNC (view_activated_cb), frame);
 
-	bonobo_view_frame_set_ui_handler (view_frame, frame->uih);
-	
 	view_widget = bonobo_view_frame_get_wrapper (view_frame);
 	
 	box = gtk_vbox_new (FALSE,0);
@@ -329,7 +329,7 @@ set_buffer_cb (BonoboUIHandler *uih, void *buffer,
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 
-	frame = get_active_frame (GTK_WIDGET(uih->top->app));
+	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		tmp = gtk_object_get_data(GTK_OBJECT(view_frame), 
@@ -346,7 +346,7 @@ view_menu_delete_window_cb (BonoboUIHandler *uih, void *data, char *path)
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 	
-	frame_close_cb(GTK_WIDGET(uih->top->app));
+	frame_close_cb (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 }
 
 static Frame *
@@ -414,7 +414,7 @@ view_menu_new_window_cb (BonoboUIHandler *uih, void *data, char *path)
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 
-	frame = get_active_frame (GTK_WIDGET(uih->top->app));
+	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		buffer = gtk_object_get_data(GTK_OBJECT(view_frame), 
@@ -437,7 +437,7 @@ view_menu_split_window_cb (BonoboUIHandler *uih, void *data, char *path)
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 
-	frame = get_active_frame (GTK_WIDGET(uih->top->app));
+	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		find_view_frame_pos (frame, view_frame, &pos);
@@ -457,7 +457,7 @@ view_menu_one_window_cb (BonoboUIHandler *uih, void *data, char *path)
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 
-	frame = get_active_frame (GTK_WIDGET(uih->top->app));
+	frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih)));
 	if ((view_frame = get_active_view_frame (frame))) {
 		for (v = frame->view_list; v;) {
 			vf = (BonoboViewFrame *)v->data;
@@ -479,7 +479,7 @@ file_menu_kill_cb (BonoboUIHandler *uih, void *data, char *path)
 	g_return_if_fail(uih != NULL);
 	g_return_if_fail(BONOBO_IS_UI_HANDLER(uih));
 
-	if (!(frame = get_active_frame (GTK_WIDGET(uih->top->app)))) return;
+	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) return;
 
 	if ((view_frame = get_active_view_frame (frame))) {
 		buffer = gtk_object_get_data(GTK_OBJECT(view_frame), 
