@@ -1,7 +1,7 @@
 /*
  * sample-container.c
  *
- *  This program is a sample Bonobo container. It allows the user to select
+ * This program is a sample Bonobo container. It allows the user to select
  * an arbitrary component for inclusion, and to render an arbritary number of
  * views of that component. It also affords easy testing of PersistStream and
  * PersistFile interfaces.
@@ -205,12 +205,19 @@ static void
 component_add_view (Component *component)
 {
 	BonoboViewFrame *view_frame;
-	GtkWidget *view_widget;
+	GtkWidget       *view_widget;
 
 	/*
-	 * Create the remote view and the local ViewFrame.
+	 * Create the remote view and the local ViewFrame.  This also
+	 * sets the BonoboUIHandler for this ViewFrame.  That way, the
+	 * embedded component can get access to our UIHandler server
+	 * so that it can merge menu and toolbar items when it gets
+	 * activated.
 	 */
-	view_frame = bonobo_client_site_new_view (component->client_site);
+	view_frame = bonobo_client_site_new_view (
+		component->client_site,
+		bonobo_object_corba_objref (BONOBO_OBJECT (
+			component->container->uih)));
 
 	/*
 	 * Connect to the "system_exception" signal on the
@@ -221,14 +228,6 @@ component_add_view (Component *component)
 	gtk_signal_connect (GTK_OBJECT (view_frame), "system_exception",
 			    component_view_frame_system_exception_cb, component);
 
-	/*
-	 * Set the BonoboUIHandler for this ViewFrame.  That way, the
-	 * embedded component can get access to our UIHandler server
-	 * so that it can merge menu and toolbar items when it gets
-	 * activated.
-	 */
-	bonobo_view_frame_set_ui_handler (view_frame, component->container->uih);
-
 	/*
 	 * Embed the view frame into the application.
 	 */
@@ -346,7 +345,7 @@ component_load_pf_ok_cb (GtkWidget *button, Component *component)
 	 * component.
 	 */
 	persist = bonobo_object_client_query_interface (component->server,
-						       "IDL:GNOME/PersistFile:1.0",
+						       "IDL:Bonobo/PersistFile:1.0",
 						       NULL);
 
 	/*
@@ -434,7 +433,7 @@ component_load_ps_ok_cb (GtkWidget *button, Component *component)
 	 * component.
 	 */
 	persist = bonobo_object_client_query_interface (component->server,
-						       "IDL:GNOME/PersistStream:1.0",
+						       "IDL:Bonobo/PersistStream:1.0",
 						       NULL);
 
 	/*
@@ -589,7 +588,7 @@ container_create_component_frame (Container *container, Component *component, ch
 	 * Create the 'Load component with PersistFile' button.
 	 */
 	if (bonobo_object_client_has_interface (component->server,
-					       "IDL:GNOME/PersistFile:1.0",
+					       "IDL:Bonobo/PersistFile:1.0",
 					       NULL)) {
 		
 		button = gtk_button_new_with_label (_("Load with PersistFile"));
@@ -606,8 +605,7 @@ container_create_component_frame (Container *container, Component *component, ch
 	 * Create the 'Load component with PersistStream' button.
 	 */
 	if (bonobo_object_client_has_interface (component->server,
-					"IDL:GNOME/PersistStream:1.0",
-					       NULL)) {
+			"IDL:Bonobo/PersistStream:1.0", NULL)) {
 		button = gtk_button_new_with_label (_("Load with PersistStream"));
 
 		gtk_box_pack_start (GTK_BOX (button_hbox), button,
@@ -707,7 +705,7 @@ container_activate_component (Container *container, char *component_goad_id)
 static void
 container_add_embeddable_cmd (GtkWidget *widget, Container *container)
 {
-	char *required_interfaces[2] = { "IDL:GNOME/Embeddable:1.0", NULL };
+	char *required_interfaces[2] = { "IDL:Bonobo/Embeddable:1.0", NULL };
 	char *goad_id;
 
 	/*
